.. _swh-loader-bzr:

.. include:: README.rst

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   how-bzr-works

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
